@@ -154,13 +154,12 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Get users infomation
     async fn query_users(
         &self,
-        id: Option<uuid::Uuid>,
         username: Option<String>,
         phone: Option<String>,
         context: &C) -> Result<QueryUsersResponse, ApiError>
     {
         let context = context.clone();
-        info!("query_users({:?}, {:?}, {:?}) - X-Span-ID: {:?}", id, username, phone, context.get().0.clone());
+        info!("query_users({:?}, {:?}) - X-Span-ID: {:?}", username, phone, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
