@@ -797,7 +797,6 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn query_users(
         &self,
-        param_id: Option<uuid::Uuid>,
         param_username: Option<String>,
         param_phone: Option<String>,
         context: &C) -> Result<QueryUsersResponse, ApiError>
@@ -811,10 +810,6 @@ impl<S, C> Api<C> for Client<S, C> where
         // Query parameters
         let query_string = {
             let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            if let Some(param_id) = param_id {
-                query_string.append_pair("id",
-                    &param_id.to_string());
-            }
             if let Some(param_username) = param_username {
                 query_string.append_pair("username",
                     &param_username.to_string());
