@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.1.1";
+pub const API_VERSION: &'static str = "0.1.2";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -105,7 +105,6 @@ pub trait Api<C: Send + Sync> {
     /// Get users infomation
     async fn query_users(
         &self,
-        id: Option<uuid::Uuid>,
         username: Option<String>,
         phone: Option<String>,
         context: &C) -> Result<QueryUsersResponse, ApiError>;
@@ -145,7 +144,6 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Get users infomation
     async fn query_users(
         &self,
-        id: Option<uuid::Uuid>,
         username: Option<String>,
         phone: Option<String>,
         ) -> Result<QueryUsersResponse, ApiError>;
@@ -216,13 +214,12 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Get users infomation
     async fn query_users(
         &self,
-        id: Option<uuid::Uuid>,
         username: Option<String>,
         phone: Option<String>,
         ) -> Result<QueryUsersResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().query_users(id, username, phone, &context).await
+        self.api().query_users(username, phone, &context).await
     }
 
 }
