@@ -442,23 +442,6 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
                 // Query parameters (note that non-required or collection query parameters will ignore garbage values, rather than causing a 400 response)
                 let query_params = form_urlencoded::parse(uri.query().unwrap_or_default().as_bytes()).collect::<Vec<_>>();
-                let param_id = query_params.iter().filter(|e| e.0 == "id").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_id = match param_id {
-                    Some(param_id) => {
-                        let param_id =
-                            <uuid::Uuid as std::str::FromStr>::from_str
-                                (&param_id);
-                        match param_id {
-                            Ok(param_id) => Some(param_id),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter id - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter id")),
-                        }
-                    },
-                    None => None,
-                };
                 let param_username = query_params.iter().filter(|e| e.0 == "username").map(|e| e.1.to_owned())
                     .nth(0);
                 let param_username = match param_username {
@@ -495,7 +478,6 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                 };
 
                                 let result = api_impl.query_users(
-                                            param_id,
                                             param_username,
                                             param_phone,
                                         &context
